==> gc_board_0.09.00.tar.gz: gc_board_0.09.00/include/gc_board_lib.php <==
<?php
///////////////////////////////////////////////////////////////////////////
// gc_board_lib.php
// Խǿ ϴ ⺻ Լ 
// 2005. 7. 21.
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  
///////////////////////////////////////////////////////////////////////////
require_once "../include/gc_lib.php";
require_once "../include/gc_output_lib.php";

///////////////////////////////////////////////////////////////////////////
// Խ ⺻  о Լ
//
// tblname	: Խ ID
//
// return :  Խ  迭
///////////////////////////////////////////////////////////////////////////
function get_board_info($tblname)
{
	global $connect;
	
	$query = "select * from gc_board_info where tblname='$tblname'";
	$row = gc_query($query);

	// ȿ tblname Ǵ
	if ($row == 0)
		out_error($tblname." ̸  Խ ϴ.");

	return $row[0];
}

///////////////////////////////////////////////////////////////////////////
//  α  Խ  Ȯϴ Լ
//
// member_id	: Ȯ  ȸ ID
// tblname		:  Խ ID
//
// return 	: ̸ 'true'. ƴϸ 'false'
///////////////////////////////////////////////////////////////////////////
function chk_board_admin($member_id, $tblname)
{
	global $connect, $sesLEVEL;

	// member_id ٸ 翬 ڰ ƴϴ.
	if (empty($member_id))
		return false;

	// ְ root    ش.
	if ($sesLEVEL == 1)
		return true;

	$admin_chk_query = "select count(*) as cnt from gc_board_masters"
				." where tblname='$tblname' and member_id='$member_id'";
	$admin_chk_row = gc_query($admin_chk_query);

	if ($admin_chk_row == 0)
		return false;
	if ($admin_chk_row[0]["cnt"] >= 1)
		return true;
	else
		return false;
}

///////////////////////////////////////////////////////////////////////////
// Խ  Ȯϴ Լ
//
// Խ Ѱ α   Ͽ  ִ   
// ǺѴ.
// Խ ̰ų  ̻    Ѵ.
//
// write_auth	: Խ  
// comment_auth	: Խ ڸƮ  
// list_auth	: Խ  б 
// read_auth	: Խ б 
// delete_auth	: Խ  
// member_id	: α  ID
// level		: α  
// tblname		:  Խ ID
//
// return 	: ѿ  迭. 迭   .
//		"write"=>[true/false], "read"=>[true/false], "delete"=>[true/false]
///////////////////////////////////////////////////////////////////////////
function get_authok($write_auth, $comment_auth, $list_auth, $read_auth
		, $delete_auth, $member_id, $level, $tblname)
{
	global $connect;
	
	//  Ȯ
	if (chk_board_admin($member_id, $tblname))
		return array("write"=>true, "comment"=>true, "list"=>true
					, "read"=>true, "delete"=>true);

	// մ 
	if (empty($member_id) and empty($level))
		$level = 12;

	$wauth_ok = false;
	$cauth_ok = false;
	$lauth_ok = false;
	$rauth_ok = false;
	$dauth_ok = false;
	if ($write_auth >= $level)
		$wauth_ok = true;
	if ($comment_auth >= $level)
		$cauth_ok = true;
	if ($list_auth >= $level)
		$lauth_ok = true;
	if ($read_auth >= $level)
		$rauth_ok = true;
	if ($delete_auth >= $level)
		$dauth_ok = true;

	return array("write"=>$wauth_ok, "comment"=>$cauth_ok, "list"=>$lauth_ok
				, "read"=>$rauth_ok, "delete"=>$dauth_ok);
}

///////////////////////////////////////////////////////////////////////////
// upload_size  ڷ ٲٴ Լ
//
// upload_size	: ڷ Ǿִ ε  ũ (: 2M)
//
// return 	: ڷ ٲ ε  ũ
///////////////////////////////////////////////////////////////////////////
function get_int_upload_size($upload_size)
{
	//  κ Ѵ.
	$num = substr($upload_size, sizeof($upload_size)-2);
	//  Ѵ.
	$unit = strtoupper(substr($upload_size, -1));
	
	switch ($unit)
	{
		case "M" : $num *= 1024;
		case "K" : $num *= 1024;
	}
	
	return $num;
}

///////////////////////////////////////////////////////////////////////////
//   Է , fsort_id  Լ
//
// tblname	: fsort_id  Խ  ̸
//
// return :  fsort_id
///////////////////////////////////////////////////////////////////////////
function get_fid($tblname)
{
	global $connect;

	if (empty($tblname))
		out_error("fsort_id  Խ õ ʾҽϴ.");

	$max_fsort_id_query = "select max(fsort_id) as max_fsort_id "
		."from gc_board_main_$tblname";
	$max_fsort_id_row = gc_query($max_fsort_id_query);
	if ($max_fsort_id_row == 0)
		$new_fsort_id = 1;
	else
		$new_fsort_id = $max_fsort_id_row[0]["max_fsort_id"]+1;

	return $new_fsort_id;
}

///////////////////////////////////////////////////////////////////////////
// Խù ϴ Լ
//
// write_id		:   ID
// passwd		: ϰ Է  н
//
// return 	: 
///////////////////////////////////////////////////////////////////////////
function del_writing($write_id, $passwd="")
{
	global $connect, $tblname, $sesID;

	$main_query = "select save_file_name, passwd, password('$passwd') as pw "
			.", member_id from gc_board_main_$tblname "
			."where maintext_id='$write_id'";
	$main_row = gc_query($main_query);
	if ($main_row == 0)
		out_error("߸ Դϴ.");
	$main_row = $main_row[0];

	//  α ȸ   Ʒ  
	if (chk_board_admin($sesID, $tblname))
		;
	// ȸ     α ȸ  Ȯ
	else if (chk_login() and ($sesID != $main_row["member_id"]))
		out_error(" ̿ܿ ڽ ۸   ֽϴ.");
	// α  ¿   н尡 ʿϴ.
	else
	{
		if ($main_row["passwd"] != $main_row["pw"])
			out_error("н尡 ġ ʽϴ.");
	}
	
	//  
	if ($main_row["save_file_name"] != "")
		@unlink($main_row["save_file_name"]);

	// comment 
	$comment_query = "delete from gc_board_comment_$tblname"
			." where maintext_id='$write_id'";
	gc_query($comment_query);

	// Խù 
	$del_query = "delete from gc_board_main_$tblname"
			." where maintext_id='$write_id'";
	gc_query($del_query);
}

///////////////////////////////////////////////////////////////////////////
// Խ ̿  include 츦 ؼ tblname  ó
// ̰  ʴ´.
///////////////////////////////////////////////////////////////////////////
if (!isset($tblname) || empty($tblname)) return ;

///////////////////////////////////////////////////////////////////////////
// Խ ⺻  
//
// ̰ Խ ⺻   κ  ν
// gc_board_lib.php ϸ Խ ⺻  ڵ о´.
///////////////////////////////////////////////////////////////////////////
$info_row = get_board_info($tblname);
$skinname		  = $info_row["skinname"];		   // Ų
$guestbook_ok	  = $info_row["guestbook_ok"];	   //    
$lattice_ok		  = $info_row["lattice_ok"];	   //    
$lattice_cols	  = $info_row["lattice_cols"];	   //     
$lattice_rows	  = $info_row["lattice_rows"];	   //     
$top_file		  = $info_row["top_file"];		   // Խ ʿ µǴ ϸ
$bottom_file	  = $info_row["bottom_file"];	   // Խ Ʒʿ µǴ ϸ
$back_file		  = $info_row["back_file"];		   // Խ Ͽ µ ϸ
$top_text		  = $info_row["top_text"];		   // Խ ʿ µǴ 
$row_per_page	  = $info_row["row_per_page"];	   //   ǥõǴ  
$pagenum_per_view = $info_row["pagenum_per_view"]; // ȭ鿡 ǥõǴ  
$reply_ok		  = $info_row["reply_ok"];		   //  㰡 
$comment_ok		  = $info_row["comment_ok"];	   // comment 㰡 
$upload_ok		  = $info_row["upload_ok"];		   // ڷ ε 㰡 
$upload_size	  = $info_row["upload_size"];	   // ִ ε 뷮
$write_auth		  = $info_row["write_auth"];	   //  
$comment_auth	  = $info_row["comment_auth"];	   // ڸƮ  
$list_auth		  = $info_row["list_auth"];		   //   
$read_auth		  = $info_row["read_auth"];		   // б 
$delete_auth	  = $info_row["delete_auth"];	   //   

//    $row_per_page  $lattice_cols * $lattice_rows
if ($lattice_ok)
	$row_per_page = $lattice_cols * $lattice_rows;

///////////////////////////////////////////////////////////////////////////
//  Ȯ
//
//  Խ Ѱ α   Ͽ  ִ 
// ȮѴ.
// Խ     ش.
///////////////////////////////////////////////////////////////////////////
$authority = get_authok($write_auth, $comment_auth, $list_auth, $read_auth
		, $delete_auth, $sesID, $sesLEVEL, $tblname);
?>

==> gc_board_0.09.01.tar.gz: gc_board_0.09.01/include/gc_board_lib.php <==
<?php
///////////////////////////////////////////////////////////////////////////
// gc_board_lib.php
// Խǿ ϴ ⺻ Լ 
// 2005. 8. 21.
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  
///////////////////////////////////////////////////////////////////////////
require_once "../include/gc_lib.php";
require_once "../include/gc_output_lib.php";

///////////////////////////////////////////////////////////////////////////
// Խ ⺻  о Լ
//
// tblname	: Խ ID
//
// return :  Խ  迭
///////////////////////////////////////////////////////////////////////////
function get_board_info($tblname)
{
	global $connect;
	
	$query = "select * from gc_board_info where tblname='$tblname'";
	$row = gc_query($query);

	// ȿ tblname Ǵ
	if ($row == 0)
		out_error($tblname." ̸  Խ ϴ.");

	return $row[0];
}

///////////////////////////////////////////////////////////////////////////
//  α  Խ  Ȯϴ Լ
//
// member_id	: Ȯ  ȸ ID
// tblname		:  Խ ID
//
// return 	: ̸ 'true'. ƴϸ 'false'
///////////////////////////////////////////////////////////////////////////
function chk_board_admin($member_id, $tblname)
{
	global $connect;

	// member_id ٸ 翬 ڰ ƴϴ.
	if (empty($member_id))
		return false;

	// ְ root    ش.
	if ($_SESSION["sesLEVEL"] == 1)
		return true;

	$admin_chk_query = "select count(*) as cnt from gc_board_masters"
				." where tblname='$tblname' and member_id='$member_id'";
	$admin_chk_row = gc_query($admin_chk_query);

	if ($admin_chk_row == 0)
		return false;
	if ($admin_chk_row[0]["cnt"] >= 1)
		return true;
	else
		return false;
}

///////////////////////////////////////////////////////////////////////////
// Խ  Ȯϴ Լ
//
// Խ Ѱ α   Ͽ  ִ   
// ǺѴ.
// Խ ̰ų  ̻    Ѵ.
//
// write_auth	: Խ  
// comment_auth	: Խ ڸƮ  
// list_auth	: Խ  б 
// read_auth	: Խ б 
// delete_auth	: Խ  
// member_id	: α  ID
// level		: α  
// tblname		:  Խ ID
//
// return 	: ѿ  迭. 迭   .
//		"write"=>[true/false], "read"=>[true/false], "delete"=>[true/false]
///////////////////////////////////////////////////////////////////////////
function get_authok($write_auth, $comment_auth, $list_auth, $read_auth
		, $delete_auth, $member_id, $level, $tblname)
{
	global $connect;
	
	//  Ȯ
	if (chk_board_admin($member_id, $tblname))
		return array("write"=>true, "comment"=>true, "list"=>true
					, "read"=>true, "delete"=>true);

	// մ 
	if (empty($member_id) and empty($level))
		$level = 12;

	$wauth_ok = false;
	$cauth_ok = false;
	$lauth_ok = false;
	$rauth_ok = false;
	$dauth_ok = false;
	if ($write_auth >= $level)
		$wauth_ok = true;
	if ($comment_auth >= $level)
		$cauth_ok = true;
	if ($list_auth >= $level)
		$lauth_ok = true;
	if ($read_auth >= $level)
		$rauth_ok = true;
	if ($delete_auth >= $level)
		$dauth_ok = true;

	return array("write"=>$wauth_ok, "comment"=>$cauth_ok, "list"=>$lauth_ok
				, "read"=>$rauth_ok, "delete"=>$dauth_ok);
}

///////////////////////////////////////////////////////////////////////////
// upload_size  ڷ ٲٴ Լ
//
// upload_size	: ڷ Ǿִ ε  ũ (: 2M)
//
// return 	: ڷ ٲ ε  ũ
///////////////////////////////////////////////////////////////////////////
function get_int_upload_size($upload_size)
{
	//  κ Ѵ.
	$num = substr($upload_size, sizeof($upload_size)-2);
	//  Ѵ.
	$unit = strtoupper(substr($upload_size, -1));
	
	switch ($unit)
	{
		case "M" : $num *= 1024;
		case "K" : $num *= 1024;
	}
	
	return $num;
}

///////////////////////////////////////////////////////////////////////////
//   Է , fsort_id  Լ
//
// tblname	: fsort_id  Խ  ̸
//
// return :  fsort_id
///////////////////////////////////////////////////////////////////////////
function get_fid($tblname)
{
	global $connect;

	if (empty($tblname))
		out_error("fsort_id  Խ õ ʾҽϴ.");

	$max_fsort_id_query = "select max(fsort_id) as max_fsort_id "
		."from gc_board_main_$tblname";
	$max_fsort_id_row = gc_query($max_fsort_id_query);
	if ($max_fsort_id_row == 0)
		$new_fsort_id = 1;
	else
		$new_fsort_id = $max_fsort_id_row[0]["max_fsort_id"]+1;

	return $new_fsort_id;
}

///////////////////////////////////////////////////////////////////////////
// Խù ϴ Լ
//
// write_id		:   ID
// passwd		: ϰ Է  н
//
// return 	: 
///////////////////////////////////////////////////////////////////////////
function del_writing($write_id, $passwd="")
{
	global $connect, $tblname;

	$main_query = "select save_file_name, passwd, password('$passwd') as pw "
			.", member_id from gc_board_main_$tblname "
			."where maintext_id='$write_id'";
	$main_row = gc_query($main_query);
	if ($main_row == 0)
		out_error("߸ Դϴ.");
	$main_row = $main_row[0];

	//  α ȸ   Ʒ  
	if (chk_board_admin($_SESSION["sesID"], $tblname))
		;
	// ȸ     α ȸ  Ȯ
	else if (chk_login() and ($_SESSION["sesID"] != $main_row["member_id"]))
		out_error(" ̿ܿ ڽ ۸   ֽϴ.");
	// α  ¿   н尡 ʿϴ.
	else
	{
		if ($main_row["passwd"] != $main_row["pw"])
			out_error("н尡 ġ ʽϴ.");
	}
	
	//  
	if ($main_row["save_file_name"] != "")
		@unlink($main_row["save_file_name"]);

	// comment 
	$comment_query = "delete from gc_board_comment_$tblname"
			." where maintext_id='$write_id'";
	gc_query($comment_query);

	// Խù 
	$del_query = "delete from gc_board_main_$tblname"
			." where maintext_id='$write_id'";
	gc_query($del_query);
}

///////////////////////////////////////////////////////////////////////////
// Խ ̿  include 츦 ؼ tblname  ó
// ̰  ʴ´.
///////////////////////////////////////////////////////////////////////////
if (!isset($tblname) || empty($tblname)) return ;

///////////////////////////////////////////////////////////////////////////
// Խ ⺻  
//
// ̰ Խ ⺻   κ  ν
// gc_board_lib.php ϸ Խ ⺻  ڵ о´.
///////////////////////////////////////////////////////////////////////////
$info_row = get_board_info($tblname);
$skinname		  = $info_row["skinname"];		   // Ų
$guestbook_ok	  = $info_row["guestbook_ok"];	   //    
$lattice_ok		  = $info_row["lattice_ok"];	   //    
$lattice_cols	  = $info_row["lattice_cols"];	   //     
$lattice_rows	  = $info_row["lattice_rows"];	   //     
$top_file		  = $info_row["top_file"];		   // Խ ʿ µǴ ϸ
$bottom_file	  = $info_row["bottom_file"];	   // Խ Ʒʿ µǴ ϸ
$back_file		  = $info_row["back_file"];		   // Խ Ͽ µ ϸ
$top_text		  = $info_row["top_text"];		   // Խ ʿ µǴ 
$row_per_page	  = $info_row["row_per_page"];	   //   ǥõǴ  
$pagenum_per_view = $info_row["pagenum_per_view"]; // ȭ鿡 ǥõǴ  
$reply_ok		  = $info_row["reply_ok"];		   //  㰡 
$comment_ok		  = $info_row["comment_ok"];	   // comment 㰡 
$upload_ok		  = $info_row["upload_ok"];		   // ڷ ε 㰡 
$upload_size	  = $info_row["upload_size"];	   // ִ ε 뷮
$write_auth		  = $info_row["write_auth"];	   //  
$comment_auth	  = $info_row["comment_auth"];	   // ڸƮ  
$list_auth		  = $info_row["list_auth"];		   //   
$read_auth		  = $info_row["read_auth"];		   // б 
$delete_auth	  = $info_row["delete_auth"];	   //   

//    $row_per_page  $lattice_cols * $lattice_rows
if ($lattice_ok)
	$row_per_page = $lattice_cols * $lattice_rows;

///////////////////////////////////////////////////////////////////////////
//  Ȯ
//
//  Խ Ѱ α   Ͽ  ִ 
// ȮѴ.
// Խ     ش.
///////////////////////////////////////////////////////////////////////////
$authority = get_authok($write_auth, $comment_auth, $list_auth, $read_auth
		, $delete_auth, $_SESSION["sesID"], $_SESSION["sesLEVEL"], $tblname);
?>
